Index: main/waeup.sirp/trunk/src/waeup/sirp/utils/helpers.py
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/utils/helpers.py	(revision 7175)
+++ main/waeup.sirp/trunk/src/waeup/sirp/utils/helpers.py	(revision 7186)
@@ -19,5 +19,5 @@
 BUFSIZE = 8 * 1024
 
-def removeFileOrDirectory(filepath):
+def remove_file_or_directory(filepath):
     """Remove a file or directory.
 
@@ -35,5 +35,5 @@
     return
 
-def copyFileSystemTree(src, dst, overwrite=False, del_old=False):
+def copy_filesystem_tree(src, dst, overwrite=False, del_old=False):
     """Copy contents of directory src to directory dst.
 
@@ -68,5 +68,5 @@
         if os.path.exists(itemdst):
             if overwrite is True:
-                removeFileOrDirectory(itemdst)
+                remove_file_or_directory(itemdst)
             else:
                 not_copied.append(item)
@@ -78,9 +78,9 @@
             shutil.copy2(itemsrc, itemdst)
         if del_old:
-            removeFileOrDirectory(itemsrc)
+            remove_file_or_directory(itemsrc)
     return not_copied
 
 
-def getInnerHTMLPart(html_code):
+def get_inner_HTML_part(html_code):
     """Return the 'inner' part of a complete HTML snippet.
 
@@ -95,5 +95,5 @@
 
        >>> doc = '<html><form>My Form</form>Outside the form</html>'
-       >>> getInnerHTMLPart(doc)
+       >>> get_inner_HTML_part(doc)
        '<form>My Form</form>'
 
@@ -101,5 +101,5 @@
 
        >>> doc = '<html><body>My Body</body>Trailing Trash</html>'
-       >>> getInnerHTMLPart(doc)
+       >>> get_inner_HTML_part(doc)
        'My Body'
 
@@ -107,5 +107,5 @@
 
        >>> doc = '<html>without body nor form</html>'
-       >>> getInnerHTMLPart(doc)
+       >>> get_inner_HTML_part(doc)
        '<html>without body nor form</html>'
 
@@ -309,5 +309,5 @@
     if warning_msgs == '':
         warning_msgs = None
-    result = getInnerHTMLPart(fulldoc).strip()
+    result = get_inner_HTML_part(fulldoc).strip()
     if not isinstance(result, unicode):
         result = result.decode('utf-8')
Index: main/waeup.sirp/trunk/src/waeup/sirp/utils/helpers.txt
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/utils/helpers.txt	(revision 7175)
+++ main/waeup.sirp/trunk/src/waeup/sirp/utils/helpers.txt	(revision 7186)
@@ -8,18 +8,18 @@
 .. :doctest:
 
-:func:`removeFileOrDirectory`
-=============================
-
-.. function:: removeFileOrDirectory(path)
+:func:`remove_file_or_directory`
+================================
+
+.. function:: remove_file_or_directory(path)
 
    Removes a file or directory given by a path. We can remove files:
 
      >>> import os
-     >>> from waeup.sirp.utils.helpers import removeFileOrDirectory
+     >>> from waeup.sirp.utils.helpers import remove_file_or_directory
      >>> open('blah', 'wb').write('nonsense')
      >>> 'blah' in os.listdir('.')
      True
 
-     >>> removeFileOrDirectory('blah')
+     >>> remove_file_or_directory('blah')
      >>> 'blah' in os.listdir('.')
      False
@@ -31,13 +31,13 @@
      True
 
-     >>> removeFileOrDirectory('blah')
+     >>> remove_file_or_directory('blah')
      >>> 'blah' in os.listdir('.')
      False
 
 
-:func:`copyFileSystemTree`
-==========================
-
-.. function:: copyFileSystemTree(src_path, dst_path[, overwrite=False[, del_old=False]])
+:func:`copy_filesystem_tree`
+============================
+
+.. function:: ccopy_filesystem_tree(src_path, dst_path[, overwrite=False[, del_old=False]])
 
    Copies the contents of an (existing) directory to another
@@ -67,6 +67,6 @@
      >>> open(os.path.join('src', 'blah'), 'wb').write('nonsense')
 
-     >>> from waeup.sirp.utils.helpers import copyFileSystemTree
-     >>> result = copyFileSystemTree('src', 'dst')
+     >>> from waeup.sirp.utils.helpers import copy_filesystem_tree
+     >>> result = copy_filesystem_tree('src', 'dst')
 
    As a result we get a list of non-copied files:
@@ -83,5 +83,5 @@
 
      >>> open(os.path.join('src', '.blah'), 'wb').write('nonsense')
-     >>> result = copyFileSystemTree('src', 'dst')
+     >>> result = copy_filesystem_tree('src', 'dst')
      >>> '.blah' in os.listdir('dst')
      False
@@ -100,5 +100,5 @@
 
     >>> open(os.path.join('src', 'blah'), 'wb').write('newnonsense')
-    >>> result = copyFileSystemTree('src', 'dst')
+    >>> result = copy_filesystem_tree('src', 'dst')
     >>> open(os.path.join('dst', 'blah'), 'rb').read()
     'nonsense'
@@ -113,5 +113,5 @@
 overwritten:
 
-    >>> result = copyFileSystemTree('src', 'dst', overwrite=True)
+    >>> result = copy_filesystem_tree('src', 'dst', overwrite=True)
     >>> open(os.path.join('dst', 'blah'), 'rb').read()
     'newnonsense'
@@ -129,5 +129,5 @@
     ...   'dst', 'mydir', 'blah'), 'wb').write('dstblah')
 
-    >>> result = copyFileSystemTree('src', 'dst', overwrite=True)
+    >>> result = copy_filesystem_tree('src', 'dst', overwrite=True)
     >>> open(os.path.join('dst', 'mydir', 'blah'), 'rb').read()
     'srcblah'
@@ -140,5 +140,5 @@
 removed from the src dir. Default is `False`.
 
-    >>> result = copyFileSystemTree('src', 'dst', overwrite=True, 
+    >>> result = copy_filesystem_tree('src', 'dst', overwrite=True,
     ...                                           del_old=True)
     >>> os.listdir('src')
@@ -151,12 +151,12 @@
 Clean up:
 
-    >>> removeFileOrDirectory('src')
-    >>> removeFileOrDirectory('dst')
-
-
-:func:`getInnerHTMLPart()`
-==========================
-
-.. function:: getInnerHTMLPart(html_code)
+    >>> remove_file_or_directory('src')
+    >>> remove_file_or_directory('dst')
+
+
+:func:`get_inner_HTML_part()`
+=============================
+
+.. function:: get_inner_HTML_part(html_code)
 
    Get the 'inner' part out of a piece of HTML code.
@@ -172,6 +172,6 @@
    returned with all preceeding/following stuff stripped:
 
-     >>> from waeup.sirp.utils.helpers import getInnerHTMLPart
-     >>> print getInnerHTMLPart("""<html>
+     >>> from waeup.sirp.utils.helpers import get_inner_HTML_part
+     >>> print get_inner_HTML_part("""<html>
      ... <head>
      ... </head>
@@ -198,5 +198,5 @@
    If there is no ``<form>`` part, try to find any ``<body>`` part:
 
-     >>> print getInnerHTMLPart("""<html>
+     >>> print get_inner_HTML_part("""<html>
      ... <head>
      ... </head>
@@ -213,5 +213,5 @@
    If there is also no ``<body>`` tag, we return the input as-is:
 
-     >>> print getInnerHTMLPart("""<div>
+     >>> print get_inner_HTML_part("""<div>
      ...  <div>Some content</div>
      ... </div>
Index: main/waeup.sirp/trunk/src/waeup/sirp/utils/tests/test_helpers.py
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/utils/tests/test_helpers.py	(revision 7175)
+++ main/waeup.sirp/trunk/src/waeup/sirp/utils/tests/test_helpers.py	(revision 7186)
@@ -54,10 +54,10 @@
 
     def test_handle_not_existing_path(self):
-        result = helpers.removeFileOrDirectory(self.non_file)
+        result = helpers.remove_file_or_directory(self.non_file)
         self.assertTrue(result is None)
         return
 
     def test_handle_dir(self):
-        helpers.removeFileOrDirectory(self.dirpath)
+        helpers.remove_file_or_directory(self.dirpath)
         self.assertFalse(
             os.path.exists(self.dirpath)
@@ -66,5 +66,5 @@
 
     def test_handle_file(self):
-        helpers.removeFileOrDirectory(self.filepath)
+        helpers.remove_file_or_directory(self.filepath)
         self.assertFalse(
             os.path.exists(self.filepath)
@@ -73,5 +73,5 @@
 
 class CopyFileSystemTreeTestCase(unittest.TestCase):
     # Test edge cases of copyFileSystemTree().
     #
     # This is a typical case of tests not written as doctest as it is
@@ -94,5 +94,5 @@
 
     def test_source_and_dst_existing(self):
-        helpers.copyFileSystemTree(self.existing_src, self.existing_dst)
+        helpers.copy_filesystem_tree(self.existing_src, self.existing_dst)
         self.assertTrue(
             os.path.exists(
@@ -105,5 +105,5 @@
         self.assertRaises(
             ValueError,
-            helpers.copyFileSystemTree,
+            helpers.copy_filesystem_tree,
             self.not_existing_dir,
             self.existing_dst
@@ -114,5 +114,5 @@
         self.assertRaises(
             ValueError,
-            helpers.copyFileSystemTree,
+            helpers.copy_filesystem_tree,
             self.existing_src,
             self.not_existing_dir
@@ -123,5 +123,5 @@
         self.assertRaises(
             ValueError,
-            helpers.copyFileSystemTree,
+            helpers.copy_filesystem_tree,
             self.filepath,
             self.existing_dst
@@ -132,5 +132,5 @@
         self.assertRaises(
             ValueError,
-            helpers.copyFileSystemTree,
+            helpers.copy_filesystem_tree,
             self.existing_src,
             self.filepath
@@ -73,5 +73,5 @@
 
 class CopyFileSystemTreeTestCase(unittest.TestCase):
-    # Test edge cases of copyFileSystemTree().
+    # Test edge cases of copy_filesystem_tree().
     #
     # This is a typical case of tests not written as doctest as it is
